/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.message.singlemessage;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Toolkit;
import java.text.SimpleDateFormat;
import javax.swing.JFrame;
import nl.cloudfarming.client.message.api.Message;
import nl.cloudfarming.client.message.api.MessageApiModule;
import nl.cloudfarming.client.message.api.MessageEvent;
import nl.cloudfarming.client.message.api.MessageEventKey;
import nl.cloudfarming.client.message.api.MessageEventProducer;
import org.openide.util.NbBundle;

/**
 * A popup window (JFrame) to display a single Message
 * 
 * @author Gerben Feenstra
 */
public class SingleMessageFrame extends JFrame {

    public SingleMessageFrame(){
        
    }
    
    public SingleMessageFrame(Message message){
        initSingleMessageFrame(message);
    }
    
    /**
     * Create a window to display the specified message
     * @param message The Message to display in this window
     */
    public final void initSingleMessageFrame(Message message){

        // Create frametitle
        StringBuilder titleSb = new StringBuilder();
        
        
        titleSb.append(new SimpleDateFormat(NbBundle.getMessage(MessageApiModule.class, "message.api.datereceived.format")).format(message.getDateReceived()));
        titleSb.append(" - ");
        titleSb.append(message.getTitle());         
        
        // Set frame
        this.setTitle(titleSb.toString());       
        this.setResizable(true);
        this.setPreferredSize(new Dimension(600, 400));
        this.setLayout(new BorderLayout());

        // Get message display panel
        this.add(new SingleMessageDisplayPropertyPanel(message), BorderLayout.NORTH);
        this.add(new SingleMessageDisplayContentPanel(message, NbBundle.getMessage(MessageApiModule.class, "message.api.notifier.label.content.text") + ":"), BorderLayout.CENTER);

        this.pack();
        
        // Center the popup
        Toolkit tk = Toolkit.getDefaultToolkit();
        Dimension d = tk.getScreenSize();
        this.setLocation((int) (d.getWidth() - this.getWidth()) / 2, (int) (d.getHeight() - this.getHeight()) / 2);

        // Activate frame
        this.setVisible(true);
              
        // Trigger event
        new MessageEventProducer().triggerEvent(new MessageEvent(message, MessageEventKey.MESSAGE_READ)); 
        
        // Set message as read
        message.setRead(true);
        this.setVisible(true);
    }

}


